##  Configuring Calculated Fields
To configure a calculated field when creating a survey, drag the Calculated field question from the left-side panel to the survey body, then add JavaScript code to the field.
You can add multiple calculated fields to a survey. Calculated fields are not shown to survey respondents, but they appear in the survey preview.
![Adding a Calculated Field to a Survey](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753e3a17a4410148205fced1aa51057_LowRes.png)
Adding a Calculated Field to a Survey
